==> owncloud-calendar_0.7.3.orig.tar.gz: calendar-0.7.3/l10n/ja.js <==
OC.L10N.register(
    "calendar",
    {
    "Not all calendars are completely cached" : "すべてのカレンダーは完全にキャッシュされていません",
    "Everything seems to be completely cached" : "すべて完全にキャッシュされていると思われます",
    "No calendars found." : "カレンダーが見つかりませんでした。",
    "No events found." : "イベントが見つかりませんでした。",
    "Wrong calendar" : "誤ったカレンダーです",
    "You do not have the permissions to edit this event." : "このイベントを編集する権限がありません。",
    "The file contained either no events or all events are already saved in your calendar." : "イベントなしまたはすべてのイベントを含むファイルは、既にあなたのカレンダーに保存されています。",
    "events have been saved in the new calendar" : "イベントは新しいカレンダーに保存されました",
    "Import failed" : "インポートに失敗",
    "events have been saved in your calendar" : "イベントはあなたのカレンダーに保存されました",
    "New Timezone:" : "新しいタイムゾーン:",
    "Timezone changed" : "タイムゾーンが変更されました",
    "Invalid request" : "無効なリクエストです",
    "Calendar" : "カレンダー",
    "Error sending mail" : "メール送信エラー",
    "Deletion failed" : "削除に失敗しました",
    "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" : "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
    "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" : "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
    "Do you really want to delete this calendar?" : "本当にこのカレンダーを削除してよろしいですか？",
    "group" : "グループ",
    "can edit" : "編集を許可",
    "can share" : "共有可",
    "ddd" : "dddd",
    "ddd M/d" : "M月d日 （dddd）",
    "dddd M/d" : "M月d日 （dddd）",
    "MMMM yyyy" : "yyyy年M月",
    "MMM d[ yyyy]{ '–'[ MMM] d yyyy}" : "yyyy年MMMMd日{ '～' yyyy年MMMMd日}",
    "dddd, MMM d, yyyy" : "yyyy年M月d日 （dddd）",
    "Sunday" : "日",
    "Monday" : "月",
    "Tuesday" : "火",
    "Wednesday" : "水",
    "Thursday" : "木",
    "Friday" : "金",
    "Saturday" : "土",
    "Sun." : "日",
    "Mon." : "月",
    "Tue." : "火",
    "Wed." : "水",
    "Thu." : "木",
    "Fri." : "金",
    "Sat." : "土",
    "January" : "1月",
    "February" : "2月",
    "March" : "3月",
    "April" : "4月",
    "May" : "5月",
    "June" : "6月",
    "July" : "7月",
    "August" : "8月",
    "September" : "9月",
    "October" : "10月",
    "November" : "11月",
    "December" : "12月",
    "Jan." : "1月",
    "Feb." : "2月",
    "Mar." : "3月",
    "Apr." : "4月",
    "May." : "5月",
    "Jun." : "6月",
    "Jul." : "7月",
    "Aug." : "8月",
    "Sep." : "9月",
    "Oct." : "10月",
    "Nov." : "11月",
    "Dec." : "12月",
    "All day" : "終日",
    "New Calendar" : "新しいカレンダーを作成",
    "Missing or invalid fields" : "不明もしくは無効なフィールド",
    "Title" : "タイトル",
    "From Date" : "開始日",
    "From Time" : "開始時間",
    "To Date" : "終了日",
    "To Time" : "終了時間",
    "The event ends before it starts" : "イベント終了時間が開始時間より先です",
    "There was a database fail" : "データベースのエラーがありました",
    "Interval is not valid. It must be a positive integer!" : "間隔に指定した値は無効です．正の整数を指定してください！",
    "Birthday" : "誕生日",
    "Business" : "ビジネス",
    "Call" : "電話をかける",
    "Clients" : "顧客",
    "Deliverer" : "運送会社",
    "Holidays" : "休日",
    "Ideas" : "アイデア",
    "Journey" : "旅行",
    "Jubilee" : "記念祭",
    "Meeting" : "ミーティング",
    "Other" : "その他",
    "Personal" : "個人",
    "Projects" : "プロジェクト",
    "Questions" : "質問事項",
    "Work" : "職場",
    "by" : "による",
    "unnamed" : "無名",
    "You do not have the permissions to update this calendar." : "このカレンダーを更新する権限がありません。",
    "You do not have the permissions to delete this calendar." : "このカレンダーを削除する権限がありません。",
    "You do not have the permissions to add to this calendar." : "このカレンダーに追加する権限がありません。",
    "You do not have the permissions to add events to this calendar." : "このカレンダーにイベントを追加する権限がありません。",
    "You cannot add non-public events to a shared calendar." : "共有カレンダーに非公開のイベントを追加することはできません。",
    "You do not have the permissions to delete this event." : "このイベントを削除する権限がありません。",
    "Busy" : "多忙",
    "Show full event" : "すべてのイベントを表示",
    "Show only busy" : "実行中のみを表示",
    "Hide event" : "イベントを非表示",
    "Does not repeat" : "繰り返さない",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Every Weekday" : "平日は毎日",
    "Bi-Weekly" : "2週間ごと",
    "Monthly" : "毎月",
    "Yearly" : "毎年",
    "never" : "なし",
    "by occurrences" : "回数で指定",
    "by date" : "日付で指定",
    "by monthday" : "日にちで指定",
    "by weekday" : "曜日で指定",
    "events week of month" : "予定のある週を指定",
    "first" : "１週目",
    "second" : "２週目",
    "third" : "３週目",
    "fourth" : "４週目",
    "fifth" : "５週目",
    "last" : "最終週",
    "by events date" : "日付で指定",
    "by yearday(s)" : "日番号で指定",
    "by weeknumber(s)" : "週番号で指定",
    "by day and month" : "月と日で指定",
    "Contact birthdays" : "連絡先の誕生日",
    "Date" : "日付",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今日",
    "CalDav Link" : "CalDavへのリンク",
    "Timezone" : "タイムゾーン",
    "Update timezone automatically" : "自動的にタイムゾーンを更新",
    "Time format" : "時刻の表示形式",
    "24h" : "24h",
    "12h" : "12h",
    "Start week on" : "1週間の初めの曜日",
    "Cache" : "キャッシュ",
    "Clear cache for repeating events" : "繰り返しイベントのキャッシュをクリア",
    "Primary CalDAV address" : "一番目の CalDAV アドレス",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス",
    "Share Calendar" : "カレンダーを共有する",
    "Download" : "ダウンロード",
    "Edit" : "編集",
    "Delete" : "削除",
    "New calendar" : "新しいカレンダー",
    "Edit calendar" : "カレンダーを編集",
    "Edit event" : "イベントを編集",
    "Save event" : "イベントを保存",
    "Delete event" : "イベントを削除",
    "Eventinfo" : "イベント情報",
    "Repeating" : "繰り返し",
    "Alarm" : "アラーム",
    "Attendees" : "参加者",
    "Share" : "共有",
    "Title of the Event" : "イベントのタイトル",
    "from" : "開始",
    "to" : "終了",
    "All Day Event" : "終日イベント",
    "Advanced options" : "詳細設定",
    "Location" : "場所",
    "Categories (separate by comma)" : "カテゴリ(カンマ区切り)",
    "Edit categories" : "カテゴリを編集",
    "Description" : "メモ",
    "Export event" : "イベントをエクスポート",
    "Repeat" : "繰り返し",
    "Advanced" : "詳細設定",
    "Select weekdays" : "曜日を指定",
    "Select days" : "日付を指定",
    "and the events day of year." : "対象の年を選択する。",
    "and the events day of month." : "対象の月を選択する。",
    "Select months" : "月を指定する",
    "Select weeks" : "週を指定する",
    "and the events week of year." : "対象の週を選択する。",
    "Interval" : "間隔",
    "End" : "繰り返す期間",
    "occurrences" : "回繰り返す",
    "Visibility to people shared with" : "共有者への可視性",
    "create a new calendar" : "新規カレンダーの作成",
    "Import a calendar file" : "カレンダーファイルをインポート",
    "Please choose a calendar" : "カレンダーを選択してください",
    "Name of new calendar" : "新規カレンダーの名称",
    "Take an available name!" : "利用可能な名前を指定してください！",
    "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." : "このカレンダー名はすでに使われています。もし続行する場合は、これらのカレンダーはマージされます。",
    "Remove all events from the selected calendar" : "選択したカレンダーからすべてのイベントを削除",
    "Import" : "インポート",
    "Close Dialog" : "ダイアログを閉じる",
    "Create a new event" : "新しいイベントを作成",
    "Create event" : "イベントを作成",
    "Share with user or group" : "ユーザーもしくはグループと共有",
    "Unshare" : "非共有",
    "Not shared with anyone" : "誰とも共有していません",
    "Send Email" : "メールを送信",
    "Shared via calendar" : "カレンダー経由で共有中",
    "Not shared with anyone via calendar" : "カレンダーを介して誰とも共有していません",
    "View an event" : "イベントを閲覧",
    "Category" : "カテゴリー",
    "No categories selected" : "カテゴリが選択されていません",
    "%s of %s" : "%s の %s",
    "Access Class" : "公開設定",
    "From" : "開始",
    "at" : "at",
    "To" : "終了"
},
"nplurals=1; plural=0;");

==> owncloud-calendar_0.8.1.orig.tar.gz: calendar-0.8.1/l10n/ja.js <==
OC.L10N.register(
    "calendar",
    {
    "Not all calendars are completely cached" : "すべてのカレンダーは完全にキャッシュされていません",
    "Everything seems to be completely cached" : "すべて完全にキャッシュされていると思われます",
    "No calendars found." : "カレンダーが見つかりませんでした。",
    "No events found." : "イベントが見つかりませんでした。",
    "Wrong calendar" : "誤ったカレンダーです",
    "You do not have the permissions to edit this event." : "このイベントを編集する権限がありません。",
    "The file contained either no events or all events are already saved in your calendar." : "イベントなし、またはすべてのイベントを含むファイルは、すでにあなたのカレンダーに保存されています。",
    "events have been saved in the new calendar" : "イベントは新しいカレンダーに保存されました",
    "Import failed" : "インポートに失敗",
    "New Timezone:" : "新しいタイムゾーン:",
    "Timezone changed" : "タイムゾーンが変更されました",
    "Invalid request" : "無効なリクエストです",
    "Calendar" : "カレンダー",
    "Error sending mail" : "メール送信エラー",
    "Deletion failed" : "削除に失敗しました",
    "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" : "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
    "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" : "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
    "Do you really want to delete this calendar?" : "本当にこのカレンダーを削除してよろしいですか？",
    "group" : "グループ",
    "can edit" : "編集を許可",
    "can share" : "共有可",
    "ddd" : "dddd",
    "ddd M/d" : "M月d日 （dddd）",
    "dddd M/d" : "M月d日 （dddd）",
    "MMMM yyyy" : "yyyy年M月",
    "MMM d[ yyyy]{ '–'[ MMM] d yyyy}" : "yyyy年MMMMd日{ '～' yyyy年MMMMd日}",
    "dddd, MMM d, yyyy" : "yyyy年M月d日 （dddd）",
    "Sunday" : "日",
    "Monday" : "月",
    "Tuesday" : "火",
    "Wednesday" : "水",
    "Thursday" : "木",
    "Friday" : "金",
    "Saturday" : "土",
    "Sun." : "日",
    "Mon." : "月",
    "Tue." : "火",
    "Wed." : "水",
    "Thu." : "木",
    "Fri." : "金",
    "Sat." : "土",
    "January" : "1月",
    "February" : "2月",
    "March" : "3月",
    "April" : "4月",
    "May" : "5月",
    "June" : "6月",
    "July" : "7月",
    "August" : "8月",
    "September" : "9月",
    "October" : "10月",
    "November" : "11月",
    "December" : "12月",
    "Jan." : "1月",
    "Feb." : "2月",
    "Mar." : "3月",
    "Apr." : "4月",
    "May." : "5月",
    "Jun." : "6月",
    "Jul." : "7月",
    "Aug." : "8月",
    "Sep." : "9月",
    "Oct." : "10月",
    "Nov." : "11月",
    "Dec." : "12月",
    "All day" : "終日",
    "New Calendar" : "新しいカレンダーを作成",
    "Missing or invalid fields" : "不明もしくは無効なフィールド",
    "Title" : "タイトル",
    "From Date" : "開始日",
    "From Time" : "開始時間",
    "To Date" : "終了日",
    "To Time" : "終了時間",
    "The event ends before it starts" : "イベント終了時間が開始時間より先です",
    "There was a database fail" : "データベースのエラーがありました",
    "Interval is not valid. It must be a positive integer!" : "間隔に指定した値は無効です．正の整数を指定してください！",
    "Import" : "インポート",
    "Shared" : "共有中",
    "Error" : "エラー",
    "Error while sharing" : "共有でエラー発生",
    "Error while unsharing" : "共有解除でエラー発生",
    "Error while changing permissions" : "権限変更でエラー発生",
    "Shared with you and the group {group} by {owner}" : "あなたと {owner} のグループ {group} で共有中",
    "Shared with you by {owner}" : "{owner} と共有中",
    "Share with users or groups …" : "ユーザーもしくはグループと共有 ...",
    "Share with users, groups or remote users …" : "ユーザー、グループもしくはリモートユーザーと共有 ...",
    "Share" : "共有",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "次の形式で指定して他のownCloudのユーザーと、共有",
    "Share link" : "URLで共有",
    "The public link will expire no later than {days} days after it is created" : "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
    "Link" : "リンク",
    "Password protect" : "パスワード保護を有効化",
    "Password" : "パスワード",
    "Choose a password for the public link" : "URLによる共有のパスワードを入力",
    "Allow editing" : "編集許可",
    "Email link to person" : "メールリンク",
    "Send" : "送信",
    "Set expiration date" : "有効期限を設定",
    "Expiration" : "期限切れ",
    "Expiration date" : "有効期限",
    "An error occured. Please try again" : "エラーが発生しました。もう一度トライしてください。",
    "Adding user..." : "ユーザーを追加しています...",
    "remote" : "リモート",
    "Resharing is not allowed" : "再共有は許可されていません",
    "Shared in {item} with {user}" : "{item} 内で {user} と共有中",
    "Unshare" : "非共有",
    "notify by email" : "メールで通知",
    "access control" : "アクセス権限",
    "create" : "作成",
    "change" : "更新",
    "delete" : "削除",
    "Password protected" : "パスワード保護",
    "Error unsetting expiration date" : "有効期限の未設定エラー",
    "Error setting expiration date" : "有効期限の設定でエラー発生",
    "Sending ..." : "送信中...",
    "Email sent" : "メールを送信しました",
    "Warning" : "警告",
    "Birthday" : "誕生日",
    "Business" : "ビジネス",
    "Call" : "電話をかける",
    "Clients" : "顧客",
    "Deliverer" : "運送会社",
    "Holidays" : "休日",
    "Ideas" : "アイデア",
    "Journey" : "旅行",
    "Jubilee" : "記念祭",
    "Meeting" : "ミーティング",
    "Other" : "その他",
    "Personal" : "個人",
    "Projects" : "プロジェクト",
    "Questions" : "質問事項",
    "Work" : "職場",
    "by" : "による",
    "unnamed" : "無名",
    "You do not have the permissions to update this calendar." : "このカレンダーを更新する権限がありません。",
    "You do not have the permissions to delete this calendar." : "このカレンダーを削除する権限がありません。",
    "You do not have the permissions to add to this calendar." : "このカレンダーに追加する権限がありません。",
    "You do not have the permissions to add events to this calendar." : "このカレンダーにイベントを追加する権限がありません。",
    "You cannot add non-public events to a shared calendar." : "共有カレンダーに非公開のイベントを追加することはできません。",
    "You do not have the permissions to delete this event." : "このイベントを削除する権限がありません。",
    "Busy" : "多忙",
    "Show full event" : "すべてのイベントを表示",
    "Show only busy" : "実行中のみを表示",
    "Hide event" : "イベントを非表示",
    "Does not repeat" : "繰り返さない",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Every Weekday" : "平日は毎日",
    "Bi-Weekly" : "2週間ごと",
    "Monthly" : "毎月",
    "Yearly" : "毎年",
    "never" : "なし",
    "by occurrences" : "回数で指定",
    "by date" : "日付で指定",
    "by monthday" : "日にちで指定",
    "by weekday" : "曜日で指定",
    "events week of month" : "予定のある週を指定",
    "first" : "１週目",
    "second" : "２週目",
    "third" : "３週目",
    "fourth" : "４週目",
    "fifth" : "５週目",
    "last" : "最終週",
    "by events date" : "日付で指定",
    "by yearday(s)" : "日番号で指定",
    "by weeknumber(s)" : "週番号で指定",
    "by day and month" : "月と日で指定",
    "Contact birthdays" : "連絡先の誕生日",
    "Date" : "日付",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今日",
    "CalDav Link" : "CalDavへのリンク",
    "Timezone" : "タイムゾーン",
    "Update timezone automatically" : "自動的にタイムゾーンを更新",
    "Time format" : "時刻の表示形式",
    "24h" : "24h",
    "12h" : "12h",
    "Start week on" : "1週間の初めの曜日",
    "Cache" : "キャッシュ",
    "Clear cache for repeating events" : "繰り返しイベントのキャッシュをクリア",
    "Primary CalDAV address" : "一番目の CalDAV アドレス",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス",
    "Share Calendar" : "カレンダーを共有する",
    "Download" : "ダウンロード",
    "Edit" : "編集",
    "Delete" : "削除",
    "New calendar" : "新しいカレンダー",
    "Edit calendar" : "カレンダーを編集",
    "Edit event" : "イベントを編集",
    "Save event" : "イベントを保存",
    "Delete event" : "イベントを削除",
    "Eventinfo" : "イベント情報",
    "Repeating" : "繰り返し",
    "Alarm" : "アラーム",
    "Attendees" : "参加者",
    "Title of the Event" : "イベントのタイトル",
    "from" : "開始",
    "to" : "終了",
    "All Day Event" : "終日イベント",
    "Advanced options" : "詳細設定",
    "Location" : "場所",
    "Categories (separate by comma)" : "カテゴリ(カンマ区切り)",
    "Edit categories" : "カテゴリを編集",
    "Description" : "メモ",
    "Export event" : "イベントをエクスポート",
    "Repeat" : "繰り返し",
    "Advanced" : "詳細設定",
    "Select weekdays" : "曜日を指定",
    "Select days" : "日付を指定",
    "and the events day of year." : "対象の年を選択する。",
    "and the events day of month." : "対象の月を選択する。",
    "Select months" : "月を指定する",
    "Select weeks" : "週を指定する",
    "and the events week of year." : "対象の週を選択する。",
    "Interval" : "間隔",
    "End" : "繰り返す期間",
    "occurrences" : "回繰り返す",
    "Visibility to people shared with" : "共有者への可視性",
    "create a new calendar" : "新規カレンダーの作成",
    "Import a calendar file" : "カレンダーファイルをインポート",
    "Please choose a calendar" : "カレンダーを選択してください",
    "Name of new calendar" : "新規カレンダーの名称",
    "Take an available name!" : "利用可能な名前を指定してください！",
    "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." : "このカレンダー名はすでに使われています。もし続行する場合は、これらのカレンダーはマージされます。",
    "Remove all events from the selected calendar" : "選択したカレンダーからすべてのイベントを削除",
    "Close Dialog" : "ダイアログを閉じる",
    "Create a new event" : "新しいイベントを作成",
    "Create event" : "イベントを作成",
    "Share with user or group" : "ユーザーもしくはグループと共有",
    "Not shared with anyone" : "誰とも共有していません",
    "Send Email" : "メールを送信",
    "Shared via calendar" : "カレンダー経由で共有中",
    "Not shared with anyone via calendar" : "カレンダーを介して誰とも共有していません",
    "View an event" : "イベントを閲覧",
    "Category" : "カテゴリー",
    "No categories selected" : "カテゴリが選択されていません",
    "%s of %s" : "%s の %s",
    "Access Class" : "公開設定",
    "From" : "開始",
    "at" : "at",
    "To" : "終了"
},
"nplurals=1; plural=0;");
